@@ -16,6 +16,7 @@ from pygls.lsp.types import (
     Range,
     RenameFile,
     RenameFileOptions,
+    ResourceOperationKind,
     TextDocumentEdit,
     TextEdit,
     VersionedTextDocumentIdentifier,
@@ -58,6 +59,7 @@ class RefactoringConverter:
         """Get all File rename operations."""
         for old_name, new_name in self.refactoring.get_renames():
             yield RenameFile(
+                kind=ResourceOperationKind.Rename,
                 old_uri=old_name.as_uri(),
                 new_uri=new_name.as_uri(),
                 options=RenameFileOptions(
